@@ -85,6 +85,9 @@ class ClBuilderUpdateAction(Action):
 
     # список задач для действия
     tasks = [
+                {'name': 'check_vardbpkg',
+                 'method': 'Builder.check_vardbpkg(cl_builder_path)'
+                 },
                 {'name': 'check_build_run',
                  'method': 'Builder.check_build_run()'},
                 {'name': 'check_chroot_run',
@@ -214,7 +217,7 @@ class ClBuilderUpdateAction(Action):
                      {'name': 'update_packages_cache',
                       'message': __("Update packages index"),
                       'method': 'Builder.download_packages('
-                                'update.cl_update_portage_binhost,'
+                                'builder.cl_builder_portage_binhost,'
                                 'update.cl_update_package_cache)',
                       'essential': False,
                       'condition': lambda Get: (
@@ -234,6 +237,10 @@ class ClBuilderUpdateAction(Action):
                 {'name': 'reps_synchronization',
                  'group': __("System configuration"),
                  'tasks': [
+                     {'name': 'world_snapshot',
+                      'method': 'Builder.world_snapshot(cl_builder_path)',
+                      'condition': lambda Get: Get('cl_templates_locate')
+                      },
                      {'name': 'revision',
                       'message': __("Fixing the settings"),
                       'method': 'Builder.apply_templates(cl_builder_path,'
@@ -241,6 +248,10 @@ class ClBuilderUpdateAction(Action):
                                 'cl_builder_linux_datavars)',
                       'condition': lambda Get: Get('cl_templates_locate')
                       },
+                     {'name': 'world_diff',
+                      'method': 'Builder.world_diff(cl_builder_path)',
+                      'condition': lambda Get: Get('cl_templates_locate')
+                      },
                      {'name': 'dispatch_conf',
                       'message': __("Updating configuration files"),
                       'method': 'Builder.dispatchConf(None,cl_builder_path)',
@@ -423,6 +434,9 @@ class ClBuilderUpdateAction(Action):
                  'depend': (Tasks.failed() & Tasks.hasnot("interrupt") &
                             Tasks.success_all("check_build_run"))
                  },
+                {'name': 'update_other:world_snapshot_clean',
+                 'method': 'Builder.world_snapshot_clean(cl_builder_path)',
+                 },
                 # сообщение удачного завершения при обновлении ревизии
                 {'name': 'update_other:success_rev',
                  'message': __("The system was successfully updated"),
